/**************************************************************************
 **************************************************************************
 
  Program:  cj34b.c		Date: Mar 26, 2013
 
  Author:  S. Swift		        Version: 2.00
  
  Copyright 2002-2014 SOC Robotics, Inc.
 
  This file contains CJ34b Joystick functions
  and execution functions.

 ***************************************************************************	 
 ***************************************************************************/
#include "asf.h"
#include "preprocessor.h"

#include "math.h"
#include "string.h"
#include "stdarg.h"
#include "stdio.h"
#include "ctype.h"


#define   putchar3(c)  ser_PutChar(COM2,c)

char smartlimitpresent=NO,CJ34bpresent=NO,joystickmode=ON,smartjoyswitches,joystickselect,joydirection[4],joyprint=NO;
char joyrate=JOGFAST,led1state=OFF,led2state=OFF,led3state=OFF;
int  smartlimit[20],smartanchcenter[4],smartanalogch[4],joyblockcnt=0;
float joyposscale=JOYPOSSCALE,joyfeedscale=JOYFEEDSCALE;

void Delaymsec(int duration)
{
	UINT32 startTime;
	
	startTime = timer_GetTickCount();
	while(timer_GetTickCount()-startTime<duration) ;	
}

int getchar3nw(void)
{
	unsigned char c;
	
	if(ser_GetChar(COM2,&c)) return c;
	else return -1;
}

unsigned char getchar3(void)
{
	unsigned char inchar;
	int inword;
	
	while((inword=getchar3nw())==-1) ;
	inchar = inword;
	return inchar;
}

void CJ34b_Led(char led,char state)
{
	putchar3(CJ34BLED);
	putchar3(led);
	putchar3(state);
}

void CJ34b_LEDS(char state)
{
	if(state==ON) {
		CJ34b_Led(CJ34BLED1,ON);
		CJ34b_Led(CJ34BLED2,ON);
		CJ34b_Led(CJ34BLED3,ON);
	}
	else {
		CJ34b_Led(CJ34BLED1,'f');
		CJ34b_Led(CJ34BLED2,'f');
		CJ34b_Led(CJ34BLED3,'f');
	}
}

void CJ34b_Leds_Toggle(int toggles,int duration)
{
	int i;
	
	for(i=0; i<toggles; i++) {
		CJ34b_LEDS(ON);
		Delaymsec(duration);
		CJ34b_LEDS(OFF);
		Delaymsec(duration);
	}
}

void CJ34B_Read_SwitchJoy(void)
{
	char c;
	putchar3(CJ34BGETANALOGS);
	smartjoyswitches = getchar3();
	smartanalogch[0] = getchar3();
	smartanalogch[1] = getchar3();
	smartanalogch[2] = getchar3();
	smartanalogch[3] = getchar3();
}

int Check_CJ34B_Present(void)
{
	char inchar,instrg[30];
	int i=1,inword;
	UINT32 startTime;
	
	putchar3(CJ34BID);
	CJ34bpresent = NO;
	startTime = timer_GetTickCount();
	while((inword=getchar3nw())==-1) {
		if((timer_GetTickCount()-startTime)>200) return 0;
	}
	inchar = inword;
	instrg[0] = inchar;
	if(inchar!='C') return 0;
	
	while((instrg[i++]=getchar3())!=CR) ;
	instrg[i] = 0;
	
	if(!strncmp("CJ34B",instrg,5)) {
		CJ34bpresent = YES;
		CJ34b_Leds_Toggle(3,100);
		CJ34b_Led(CJ34BLED3,ON);
		joyrate = JOGFAST;
		CJ34b_Led(CJ34BLED1,ON);
		joystickselect = USECJ34BJOYSTICK;
		CJ34B_Read_SwitchJoy();
		for(i=0; i<4; i++)  smartanchcenter[i] = smartanalogch[i];
		joystickmode = ON;
	}
	return 1;
}

void Check_SmartLimit_Present(void)
{
	int i;
	
	for(i=0; i<20; i++)  smartlimit[i] = 0;
	smartlimitpresent = 0;
}

void Enumerate_Serial_Devices(void)
{
	Check_CJ34B_Present();
	if(CJ34bpresent==YES) printf(" CJ34B Joystick found\n\r");
	else printf(" No CJ34B Joystick found\n\r");
}

void Enumerate_Smart_LimitSwitches(void)
{
	Check_SmartLimit_Present();
	if(smartlimitpresent==YES) printf(" Smart Limit Switch(s) found\n\r");
	else printf(" No Smart Limit Switch(s) found\n\r");
}
